@@ -9,8 +9,8 @@ for d3.js without taking away the power that d3.js gives you.
 Project location : https://github.com/areski/django-nvd3
 """
 
-__version__ = '0.7.4'  # edit also docs/source/conf.py and update requirements.txt
-__author__ = "Arezqui Belaid"
+__version__ = '0.7.5'  # edit also docs/source/conf.py and update requirements.txt
+__author__ = "Areski Belaid"
 __contact__ = "areski@gmail.com"
-__homepage__ = "http://www.areski.net"
+__homepage__ = "http://areskibelaid.com/"
 __docformat__ = "restructuredtext"
